bubblesort

package
v0.0.0-...-81e6950 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 3, 2022 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BubbleSort

func BubbleSort(input []int, order string) ([]int, error)

BubbleSort takes a slice of integers as input and a string flag to decide sorting order and returns the sorted slice. order flag is used to determine the sorting order. Accepted values:

  • "asc": sorts slice ins ascending order.
  • "desc": sorts slice ins descending order.
  • Any other value passed returns an error.

Types

This section is empty.

Directories

Path Synopsis

Jump to