inesrtion

package
v0.0.0-...-81e6950 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 3, 2022 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Sort

func Sort(input []int, order string) ([]int, error)

Takes a slice of integers and sorting order, sorts them using the insertion sort algorithm and returns the sorted slice. Returns an error if input is empty or an invalid sorting order is specified. Expected values for sorting order are "asc" or "desc".

Types

This section is empty.

Jump to