merge

package
v0.0.0-...-81e6950 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 3, 2022 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Sort

func Sort(input []int, order string) ([]int, error)

Sort takes a slice of integers, a sorting order and returns a slice sorted using the merge sort algorithm or an error if the sorting order is invalid. order can have values: \"asc\" or \"desc\" (irrespective of case).

Types

This section is empty.

Jump to