quick

package
v0.0.0-...-81e6950 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 3, 2022 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Sort

func Sort(input []int, start, end int) []int

Sort takes in a slice of integers, its start and end indices and returns a slice sorted using the quick sort algorithm.

Types

This section is empty.

Jump to