package
Version:
v0.0.0-...-81e6950
Opens a new window with list of versions in this module.
Published: Dec 3, 2022
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func InitList() *linkedList
InitList initializes and returns the reference to a new linkedlist.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.