Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BubbleSort ¶
BubbleSort takes a slice of integers as input and a string flag to decide sorting order and returns the sorted slice. order flag is used to determine the sorting order. Accepted values:
- "asc": sorts slice ins ascending order.
- "desc": sorts slice ins descending order.
- Any other value passed returns an error.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.